package
module
Version:
v0.0.0-...-31d56bd
Opens a new window with list of versions in this module.
Published: Jul 3, 2018
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
Thanks
Usage
package main
import (
"fmt"
"github.com/chenhw2/ip2loc"
)
func main() {
if loc, err := ip2loc.IP2loc("8.8.8.8"); err != nil {
fmt.Printf("%+v", err)
} else {
fmt.Printf("%+v", loc)
}
}
Documentation
¶
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.